@@ -1,27 +1,3 @@
-#[macro_use]
-extern crate concat_with;
-extern crate clap;
-extern crate terminal_size;
-
-extern crate tokio;
-
-extern crate once_cell;
-
-extern crate dnsclient;
-
-#[cfg(feature = "json")]
-extern crate serde;
-
-#[cfg(feature = "json")]
-#[macro_use]
-extern crate serde_derive;
-
-#[cfg(feature = "json")]
-extern crate serde_json;
-
-#[cfg(any(unix, feature = "json"))]
-extern crate path_absolutize;
-
 use std::error::Error;
 use std::net::{IpAddr, Ipv4Addr, SocketAddr};
 use std::process::{self, Command};
@@ -48,9 +24,14 @@ use dnsclient::UpstreamServer;
 #[cfg(any(unix, feature = "json"))]
 use path_absolutize::Absolutize;
 
-use clap::{App, Arg, ArgMatches, Values};
+#[cfg(feature = "json")]
+use serde::Deserialize;
+
+use clap::{Arg, ArgMatches, Command as ClapCommand, Values};
 use terminal_size::terminal_size;
 
+use concat_with::concat_line;
+
 const APP_NAME: &str = "wait-service";
 const CARGO_PKG_VERSION: &str = env!("CARGO_PKG_VERSION");
 const CARGO_PKG_AUTHORS: &str = env!("CARGO_PKG_AUTHORS");
@@ -169,6 +150,7 @@ async fn wait_tcp(tcp_task: &TcpTask, timeout: Duration) -> Result<(), String> {
     Ok(())
 }
 
+#[cfg(unix)]
 async fn wait_uds_handler(uds_task: &UdsTask) -> Result<(), String> {
     while UnixStream::connect(uds_task.uds.as_str()).await.is_err() {
         sleep(SLEEP_INTERVAL).await;
@@ -334,7 +316,7 @@ async fn main() -> Result<(), Box<dyn Error>> {
 }
 
 fn get_matches() -> ArgMatches {
-    let app = App::new(APP_NAME)
+    let app = ClapCommand::new(APP_NAME)
         .term_width(terminal_size().map(|(width, _)| width.0 as usize).unwrap_or(0))
         .version(CARGO_PKG_VERSION)
         .author(CARGO_PKG_AUTHORS)
@@ -350,7 +332,7 @@ fn get_matches() -> ArgMatches {
         .short('t')
         .takes_value(true)
         .default_value(DEFAULT_TIMEOUT_SECONDS)
-        .help("Sets the timeout in seconds, zero for no timeout");
+        .help("Set the timeout in seconds, zero for no timeout");
 
     let arg_command = Arg::new("COMMAND")
         .required(true)
